==> kubernetes-model-1.1.2-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterPolicyBindingFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;

public class ClusterPolicyBindingFluentImpl<A extends ClusterPolicyBindingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterPolicyBindingFluent<A>{

    private String apiVersion;
    private String kind;
    private String lastModified;
    private ObjectMetaBuilder metadata;
    private ObjectReferenceBuilder policyRef;
    private List<NamedClusterRoleBindingBuilder> roleBindings =  new ArrayList<NamedClusterRoleBindingBuilder>();

    public ClusterPolicyBindingFluentImpl(){
    }
    public ClusterPolicyBindingFluentImpl(ClusterPolicyBinding instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withLastModified(instance.getLastModified()); 
            this.withMetadata(instance.getMetadata()); 
            this.withPolicyRef(instance.getPolicyRef()); 
            this.withRoleBindings(instance.getRoleBindings()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion!=null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind!=null;
    }

    public String getLastModified(){
            return this.lastModified;
    }

    public A withLastModified(String lastModified){
            this.lastModified=lastModified; return (A) this;
    }

    public Boolean hasLastModified(){
            return this.lastModified!=null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata!=null;
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildPolicyRef instead.
 */
@Deprecated public ObjectReference getPolicyRef(){
            return this.policyRef!=null?this.policyRef.build():null;
    }

    public ObjectReference buildPolicyRef(){
            return this.policyRef!=null?this.policyRef.build():null;
    }

    public A withPolicyRef(ObjectReference policyRef){
            _visitables.remove(this.policyRef);
            if (policyRef!=null){ this.policyRef= new ObjectReferenceBuilder(policyRef); _visitables.add(this.policyRef);} return (A) this;
    }

    public Boolean hasPolicyRef(){
            return this.policyRef!=null;
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> withNewPolicyRef(){
            return new PolicyRefNestedImpl();
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> withNewPolicyRefLike(ObjectReference item){
            return new PolicyRefNestedImpl(item);
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editPolicyRef(){
            return withNewPolicyRefLike(getPolicyRef());
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editOrNewPolicyRef(){
            return withNewPolicyRefLike(getPolicyRef() != null ? getPolicyRef(): new ObjectReferenceBuilder().build());
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editOrNewPolicyRefLike(ObjectReference item){
            return withNewPolicyRefLike(getPolicyRef() != null ? getPolicyRef(): item);
    }

    public A addToRoleBindings(int index,NamedClusterRoleBinding item){
            NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.roleBindings.add(index >= 0 ? index : roleBindings.size(), builder); return (A)this;
    }

    public A setToRoleBindings(int index,NamedClusterRoleBinding item){
            NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= roleBindings.size()) { roleBindings.add(builder); } else { roleBindings.set(index, builder);}
             return (A)this;
    }

    public A addToRoleBindings(NamedClusterRoleBinding... items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(builder);this.roleBindings.add(builder);} return (A)this;
    }

    public A addAllToRoleBindings(Collection<NamedClusterRoleBinding> items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(builder);this.roleBindings.add(builder);} return (A)this;
    }

    public A removeFromRoleBindings(NamedClusterRoleBinding... items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.remove(builder);this.roleBindings.remove(builder);} return (A)this;
    }

    public A removeAllFromRoleBindings(Collection<NamedClusterRoleBinding> items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.remove(builder);this.roleBindings.remove(builder);} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildRoleBindings instead.
 */
@Deprecated public List<NamedClusterRoleBinding> getRoleBindings(){
            return build(roleBindings);
    }

    public List<NamedClusterRoleBinding> buildRoleBindings(){
            return build(roleBindings);
    }

    public NamedClusterRoleBinding buildRoleBinding(int index){
            return this.roleBindings.get(index).build();
    }

    public NamedClusterRoleBinding buildFirstRoleBinding(){
            return this.roleBindings.get(0).build();
    }

    public NamedClusterRoleBinding buildLastRoleBinding(){
            return this.roleBindings.get(roleBindings.size() - 1).build();
    }

    public NamedClusterRoleBinding buildMatchingRoleBinding(io.fabric8.kubernetes.api.builder.Predicate<NamedClusterRoleBindingBuilder> predicate){
            for (NamedClusterRoleBindingBuilder item: roleBindings) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withRoleBindings(List<NamedClusterRoleBinding> roleBindings){
            _visitables.removeAll(this.roleBindings);
            this.roleBindings.clear();
            if (roleBindings != null) {for (NamedClusterRoleBinding item : roleBindings){this.addToRoleBindings(item);}} return (A) this;
    }

    public A withRoleBindings(NamedClusterRoleBinding... roleBindings){
            this.roleBindings.clear(); if (roleBindings != null) {for (NamedClusterRoleBinding item :roleBindings){ this.addToRoleBindings(item);}} return (A) this;
    }

    public Boolean hasRoleBindings(){
            return roleBindings!= null && !roleBindings.isEmpty();
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> addNewRoleBinding(){
            return new RoleBindingsNestedImpl();
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> addNewRoleBindingLike(NamedClusterRoleBinding item){
            return new RoleBindingsNestedImpl(-1, item);
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> setNewRoleBindingLike(int index,NamedClusterRoleBinding item){
            return new RoleBindingsNestedImpl(index, item);
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editRoleBinding(int index){
            if (roleBindings.size() <= index) throw new RuntimeException("Can't edit roleBindings. Index exceeds size.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editFirstRoleBinding(){
            if (roleBindings.size() == 0) throw new RuntimeException("Can't edit first roleBindings. The list is empty.");
            return setNewRoleBindingLike(0, buildRoleBinding(0));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editLastRoleBinding(){
            int index = roleBindings.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last roleBindings. The list is empty.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editMatchingRoleBinding(io.fabric8.kubernetes.api.builder.Predicate<NamedClusterRoleBindingBuilder> predicate){
            int index = -1;
            for (int i=0;i<roleBindings.size();i++) { 
            if (predicate.apply(roleBindings.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching roleBindings. No match found.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ClusterPolicyBindingFluentImpl that = (ClusterPolicyBindingFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (lastModified != null ? !lastModified.equals(that.lastModified) :that.lastModified != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (policyRef != null ? !policyRef.equals(that.policyRef) :that.policyRef != null) return false;
            if (roleBindings != null ? !roleBindings.equals(that.roleBindings) :that.roleBindings != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterPolicyBindingFluent.MetadataNested<N>> implements ClusterPolicyBindingFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class PolicyRefNestedImpl<N> extends ObjectReferenceFluentImpl<ClusterPolicyBindingFluent.PolicyRefNested<N>> implements ClusterPolicyBindingFluent.PolicyRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            PolicyRefNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
            PolicyRefNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.withPolicyRef(builder.build());
    }
    public N endPolicyRef(){
            return and();
    }

}
    public class RoleBindingsNestedImpl<N> extends NamedClusterRoleBindingFluentImpl<ClusterPolicyBindingFluent.RoleBindingsNested<N>> implements ClusterPolicyBindingFluent.RoleBindingsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final NamedClusterRoleBindingBuilder builder;
        private final int index;
    
            RoleBindingsNestedImpl(int index,NamedClusterRoleBinding item){
                    this.index = index;
                    this.builder = new NamedClusterRoleBindingBuilder(this, item);
            }
            RoleBindingsNestedImpl(){
                    this.index = -1;
                    this.builder = new NamedClusterRoleBindingBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.setToRoleBindings(index, builder.build());
    }
    public N endRoleBinding(){
            return and();
    }

}


}

==> kubernetes-model-2.1.2-sources.jar: annotations/io/fabric8/openshift/api/model/ClusterPolicyBindingFluentImpl.java <==
package io.fabric8.openshift.api.model;

import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import io.fabric8.kubernetes.api.model.validators.CheckObjectMeta;
import java.lang.String;
import javax.validation.constraints.NotNull;
import io.fabric8.kubernetes.api.builder.Predicate;
import io.fabric8.kubernetes.api.model.ObjectReference;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectReferenceFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import javax.validation.Valid;
import io.fabric8.kubernetes.api.model.ObjectReferenceBuilder;
import java.util.Collection;
import java.lang.Object;

public class ClusterPolicyBindingFluentImpl<A extends ClusterPolicyBindingFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements ClusterPolicyBindingFluent<A>{

    private String apiVersion;
    private String kind;
    private String lastModified;
    private ObjectMetaBuilder metadata;
    private ObjectReferenceBuilder policyRef;
    private List<NamedClusterRoleBindingBuilder> roleBindings =  new ArrayList<NamedClusterRoleBindingBuilder>();

    public ClusterPolicyBindingFluentImpl(){
    }
    public ClusterPolicyBindingFluentImpl(ClusterPolicyBinding instance){
            this.withApiVersion(instance.getApiVersion()); 
            this.withKind(instance.getKind()); 
            this.withLastModified(instance.getLastModified()); 
            this.withMetadata(instance.getMetadata()); 
            this.withPolicyRef(instance.getPolicyRef()); 
            this.withRoleBindings(instance.getRoleBindings()); 
    }

    public String getApiVersion(){
            return this.apiVersion;
    }

    public A withApiVersion(String apiVersion){
            this.apiVersion=apiVersion; return (A) this;
    }

    public Boolean hasApiVersion(){
            return this.apiVersion != null;
    }

    public String getKind(){
            return this.kind;
    }

    public A withKind(String kind){
            this.kind=kind; return (A) this;
    }

    public Boolean hasKind(){
            return this.kind != null;
    }

    public String getLastModified(){
            return this.lastModified;
    }

    public A withLastModified(String lastModified){
            this.lastModified=lastModified; return (A) this;
    }

    public Boolean hasLastModified(){
            return this.lastModified != null;
    }

    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 */
@Deprecated public ObjectMeta getMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public ObjectMeta buildMetadata(){
            return this.metadata!=null?this.metadata.build():null;
    }

    public A withMetadata(ObjectMeta metadata){
            _visitables.remove(this.metadata);
            if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.add(this.metadata);} return (A) this;
    }

    public Boolean hasMetadata(){
            return this.metadata != null;
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> withNewMetadata(){
            return new MetadataNestedImpl();
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item){
            return new MetadataNestedImpl(item);
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editMetadata(){
            return withNewMetadataLike(getMetadata());
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editOrNewMetadata(){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
    }

    public ClusterPolicyBindingFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item){
            return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
    }

    
/**
 * This method has been deprecated, please use method buildPolicyRef instead.
 */
@Deprecated public ObjectReference getPolicyRef(){
            return this.policyRef!=null?this.policyRef.build():null;
    }

    public ObjectReference buildPolicyRef(){
            return this.policyRef!=null?this.policyRef.build():null;
    }

    public A withPolicyRef(ObjectReference policyRef){
            _visitables.remove(this.policyRef);
            if (policyRef!=null){ this.policyRef= new ObjectReferenceBuilder(policyRef); _visitables.add(this.policyRef);} return (A) this;
    }

    public Boolean hasPolicyRef(){
            return this.policyRef != null;
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> withNewPolicyRef(){
            return new PolicyRefNestedImpl();
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> withNewPolicyRefLike(ObjectReference item){
            return new PolicyRefNestedImpl(item);
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editPolicyRef(){
            return withNewPolicyRefLike(getPolicyRef());
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editOrNewPolicyRef(){
            return withNewPolicyRefLike(getPolicyRef() != null ? getPolicyRef(): new ObjectReferenceBuilder().build());
    }

    public ClusterPolicyBindingFluent.PolicyRefNested<A> editOrNewPolicyRefLike(ObjectReference item){
            return withNewPolicyRefLike(getPolicyRef() != null ? getPolicyRef(): item);
    }

    public A addToRoleBindings(int index,NamedClusterRoleBinding item){
            if (this.roleBindings == null) {this.roleBindings = new ArrayList<NamedClusterRoleBindingBuilder>();}
            NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(index >= 0 ? index : _visitables.size(), builder);this.roleBindings.add(index >= 0 ? index : roleBindings.size(), builder); return (A)this;
    }

    public A setToRoleBindings(int index,NamedClusterRoleBinding item){
            if (this.roleBindings == null) {this.roleBindings = new ArrayList<NamedClusterRoleBindingBuilder>();}
            NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);
            if (index < 0 || index >= _visitables.size()) { _visitables.add(builder); } else { _visitables.set(index, builder);}
            if (index < 0 || index >= roleBindings.size()) { roleBindings.add(builder); } else { roleBindings.set(index, builder);}
             return (A)this;
    }

    public A addToRoleBindings(NamedClusterRoleBinding... items){
            if (this.roleBindings == null) {this.roleBindings = new ArrayList<NamedClusterRoleBindingBuilder>();}
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(builder);this.roleBindings.add(builder);} return (A)this;
    }

    public A addAllToRoleBindings(Collection<NamedClusterRoleBinding> items){
            if (this.roleBindings == null) {this.roleBindings = new ArrayList<NamedClusterRoleBindingBuilder>();}
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.add(builder);this.roleBindings.add(builder);} return (A)this;
    }

    public A removeFromRoleBindings(NamedClusterRoleBinding... items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.remove(builder);if (this.roleBindings != null) {this.roleBindings.remove(builder);}} return (A)this;
    }

    public A removeAllFromRoleBindings(Collection<NamedClusterRoleBinding> items){
            for (NamedClusterRoleBinding item : items) {NamedClusterRoleBindingBuilder builder = new NamedClusterRoleBindingBuilder(item);_visitables.remove(builder);if (this.roleBindings != null) {this.roleBindings.remove(builder);}} return (A)this;
    }

    
/**
 * This method has been deprecated, please use method buildRoleBindings instead.
 */
@Deprecated public List<NamedClusterRoleBinding> getRoleBindings(){
            return build(roleBindings);
    }

    public List<NamedClusterRoleBinding> buildRoleBindings(){
            return build(roleBindings);
    }

    public NamedClusterRoleBinding buildRoleBinding(int index){
            return this.roleBindings.get(index).build();
    }

    public NamedClusterRoleBinding buildFirstRoleBinding(){
            return this.roleBindings.get(0).build();
    }

    public NamedClusterRoleBinding buildLastRoleBinding(){
            return this.roleBindings.get(roleBindings.size() - 1).build();
    }

    public NamedClusterRoleBinding buildMatchingRoleBinding(io.fabric8.kubernetes.api.builder.Predicate<NamedClusterRoleBindingBuilder> predicate){
            for (NamedClusterRoleBindingBuilder item: roleBindings) { if(predicate.apply(item)){return item.build();} } return null;
    }

    public A withRoleBindings(List<NamedClusterRoleBinding> roleBindings){
            if (this.roleBindings == null) { this.roleBindings = new ArrayList<NamedClusterRoleBindingBuilder>();} else {_visitables.removeAll(this.roleBindings); this.roleBindings.clear();}
            if (roleBindings != null) {for (NamedClusterRoleBinding item : roleBindings){this.addToRoleBindings(item);}} return (A) this;
    }

    public A withRoleBindings(NamedClusterRoleBinding... roleBindings){
            this.roleBindings.clear(); if (roleBindings != null) {for (NamedClusterRoleBinding item :roleBindings){ this.addToRoleBindings(item);}} return (A) this;
    }

    public Boolean hasRoleBindings(){
            return roleBindings != null && !roleBindings.isEmpty();
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> addNewRoleBinding(){
            return new RoleBindingsNestedImpl();
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> addNewRoleBindingLike(NamedClusterRoleBinding item){
            return new RoleBindingsNestedImpl(-1, item);
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> setNewRoleBindingLike(int index,NamedClusterRoleBinding item){
            return new RoleBindingsNestedImpl(index, item);
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editRoleBinding(int index){
            if (roleBindings.size() <= index) throw new RuntimeException("Can't edit roleBindings. Index exceeds size.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editFirstRoleBinding(){
            if (roleBindings.size() == 0) throw new RuntimeException("Can't edit first roleBindings. The list is empty.");
            return setNewRoleBindingLike(0, buildRoleBinding(0));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editLastRoleBinding(){
            int index = roleBindings.size() - 1;
            if (index < 0) throw new RuntimeException("Can't edit last roleBindings. The list is empty.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public ClusterPolicyBindingFluent.RoleBindingsNested<A> editMatchingRoleBinding(io.fabric8.kubernetes.api.builder.Predicate<NamedClusterRoleBindingBuilder> predicate){
            int index = -1;
            for (int i=0;i<roleBindings.size();i++) { 
            if (predicate.apply(roleBindings.get(i))) {index = i; break;}
            } 
            if (index < 0) throw new RuntimeException("Can't edit matching roleBindings. No match found.");
            return setNewRoleBindingLike(index, buildRoleBinding(index));
    }

    public boolean equals(Object o){
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;
            if (!super.equals(o)) return false;
            ClusterPolicyBindingFluentImpl that = (ClusterPolicyBindingFluentImpl) o;
            if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
            if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
            if (lastModified != null ? !lastModified.equals(that.lastModified) :that.lastModified != null) return false;
            if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
            if (policyRef != null ? !policyRef.equals(that.policyRef) :that.policyRef != null) return false;
            if (roleBindings != null ? !roleBindings.equals(that.roleBindings) :that.roleBindings != null) return false;
            return true;
    }


    public class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterPolicyBindingFluent.MetadataNested<N>> implements ClusterPolicyBindingFluent.MetadataNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectMetaBuilder builder;
    
            MetadataNestedImpl(ObjectMeta item){
                    this.builder = new ObjectMetaBuilder(this, item);
            }
            MetadataNestedImpl(){
                    this.builder = new ObjectMetaBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata(){
            return and();
    }

}
    public class PolicyRefNestedImpl<N> extends ObjectReferenceFluentImpl<ClusterPolicyBindingFluent.PolicyRefNested<N>> implements ClusterPolicyBindingFluent.PolicyRefNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final ObjectReferenceBuilder builder;
    
            PolicyRefNestedImpl(ObjectReference item){
                    this.builder = new ObjectReferenceBuilder(this, item);
            }
            PolicyRefNestedImpl(){
                    this.builder = new ObjectReferenceBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.withPolicyRef(builder.build());
    }
    public N endPolicyRef(){
            return and();
    }

}
    public class RoleBindingsNestedImpl<N> extends NamedClusterRoleBindingFluentImpl<ClusterPolicyBindingFluent.RoleBindingsNested<N>> implements ClusterPolicyBindingFluent.RoleBindingsNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{

            private final NamedClusterRoleBindingBuilder builder;
        private final int index;
    
            RoleBindingsNestedImpl(int index,NamedClusterRoleBinding item){
                    this.index = index;
                    this.builder = new NamedClusterRoleBindingBuilder(this, item);
            }
            RoleBindingsNestedImpl(){
                    this.index = -1;
                    this.builder = new NamedClusterRoleBindingBuilder(this);
            }
    
    public N and(){
            return (N) ClusterPolicyBindingFluentImpl.this.setToRoleBindings(index, builder.build());
    }
    public N endRoleBinding(){
            return and();
    }

}


}
